==> phonon-backend-gstreamer_4.9.0.orig.tar.xz: phonon-gstreamer-4.9.0/gstreamer/gstreamer.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mp3;audio/x-ape;
X-KDE-Library=phonon_gstreamer
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_GST_VERSION@
X-KDE-PhononBackendInfo-Website=http://gstreamer.freedesktop.org/
Icon=phonon-gstreamer
InitialPreference=15

Name=GStreamer
Name[ast]=GStreamer
Name[bg]=GStreamer
Name[bs]=Gstreamer
Name[ca]=GStreamer
Name[ca@valencia]=GStreamer
Name[cs]=GStreamer
Name[da]=GStreamer
Name[de]=GStreamer
Name[el]=GStreamer
Name[en_GB]=GStreamer
Name[es]=GStreamer
Name[et]=GStreamer
Name[eu]=GStreamer
Name[fa]=GStreamer
Name[fi]=GStreamer
Name[fr]=GStreamer
Name[ga]=GStreamer
Name[gl]=GStreamer
Name[hsb]=GStreamer
Name[hu]=GStreamer
Name[id]=GStreamer
Name[is]=GStreamer
Name[it]=GStreamer
Name[ja]=GStreamer
Name[kk]=GStreamer
Name[ko]=GStreamer
Name[ku]=GStreamer
Name[lt]=GStreamer
Name[lv]=GStreamer
Name[mai]=GStreamer
Name[mr]=जी-स्ट्रीमर
Name[nb]=GStreamer
Name[nds]=GStreamer
Name[nl]=GStreamer
Name[nn]=GStreamer
Name[pa]=ਜੀਸਟੀਰਮਰ
Name[pl]=GStreamer
Name[pt]=GStreamer
Name[pt_BR]=GStreamer
Name[ro]=GStreamer
Name[ru]=GStreamer
Name[se]=GStreamer
Name[sk]=GStreamer
Name[sl]=GStreamer
Name[sr]=Гстример
Name[sr@ijekavian]=Гстример
Name[sr@ijekavianlatin]=GStreamer
Name[sr@latin]=GStreamer
Name[sv]=Gstreamer
Name[th]=GStreamer
Name[tr]=GStreamer
Name[ug]=GStreamer
Name[uk]=GStreamer
Name[x-test]=xxGStreamerxx
Name[zh_CN]=GStreamer
Name[zh_TW]=GStreamer

Comment=Phonon GStreamer backend
Comment[bg]=Phonon GStreamer
Comment[bs]=Gstreamer kao pozadina Phonona
Comment[ca]=Dorsal GStreamer del Phonon
Comment[ca@valencia]=Dorsal GStreamer del Phonon
Comment[cs]=Podpůrná vrstva GStreamer pro Phonon
Comment[da]=GStreamer-backend til Phonon
Comment[de]=Phonon-Treiber für GStreamer
Comment[el]=Σύστημα υποστήριξης GStreamer του Phonon
Comment[en_GB]=Phonon GStreamer backend
Comment[es]=Motor GStreamer para Phonon
Comment[et]=Phononi GStreameri taustaprogramm
Comment[eu]=Phonon-en GStreamer bizkarraldekoa
Comment[fa]=پسانه‌ی جی‌استریمر برای فنون (Phonon GStreamer backend)
Comment[fi]=Phonon GStreamer -taustajärjestelmä
Comment[fr]=Moteur GStreamer pour Phonon 
Comment[ga]=Inneall GStreamer le haghaidh Phonon
Comment[gl]=Infraestrutura de GStreamer para Phonon
Comment[hsb]=Phonon GStreamer backend
Comment[hu]=Phonon GStreamer-modul
Comment[id]=Phonon GStreamer backend
Comment[is]=Phonon GStreamer bakendi
Comment[it]=Motore Gstreamer di Phonon
Comment[ja]=Phonon GStreamer バックエンド
Comment[kk]=Phonon GStreamer тетігі
Comment[ko]=Phonon GStreamer 백엔드
Comment[ku]=Binesaza Phonon GStreamer
Comment[lt]=Phonon GStreamer galinė sąsaja
Comment[lv]=Phonon GStreamer aizmugure
Comment[mr]=फोनॉन जी-स्ट्रीमर बॅकएन्ड
Comment[nb]=Phonon-motor for GStreamer
Comment[nds]=GStreamer-Hülpprogramm för Phonon
Comment[nl]=GStreamer-backend (Phonon)
Comment[nn]=Phonon-motor for GStreamer
Comment[pa]=ਫੋਨੋਨ ਜਸਟੀਰਮਰ ਬੈਕਐਂਡ
Comment[pl]=Obsługa GStreamera przez Phonon
Comment[pt]=Infra-estrutura do GStreamer para o Phonon
Comment[pt_BR]=Infraestrutura do GStreamer para o Phonon
Comment[ro]=Suportul GStreamer pentru Phonon
Comment[ru]=Механизм GStreamer для Phonon
Comment[se]=Phonon GStreamer duogášmohtor
Comment[sk]=Podsystém Phonon GStreamer
Comment[sl]=Zaledje GStreamer za Phonon
Comment[sr]=Гстример као позадина Фонона
Comment[sr@ijekavian]=Гстример као позадина Фонона
Comment[sr@ijekavianlatin]=GStreamer kao pozadina Phonona
Comment[sr@latin]=GStreamer kao pozadina Phonona
Comment[sv]=Phonon Gstreamer-gränssnitt
Comment[th]=โปรแกรมเบื้องหลัง GStreamer ของ Phonon
Comment[tr]=Phonon GStreamer arka ucu
Comment[ug]=Phonon GStreamer نىڭ ئارقائۇچى
Comment[uk]=Модуль використання GStreamer у Phonon
Comment[x-test]=xxPhonon GStreamer backendxx
Comment[zh_CN]=Phonon GStreamer 后端
Comment[zh_TW]=Phonon GStreamer 後端介面

==> phonon-backend-gstreamer-4.9.1.tar.xz: phonon-gstreamer-4.9.1/gstreamer/gstreamer.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=PhononBackend
MimeType=application/x-annodex;video/quicktime;video/x-quicktime;audio/x-m4a;application/x-quicktimeplayer;video/mkv;video/msvideo;video/x-msvideo;video/x-flic;audio/x-aiff;audio/aiff;audio/x-pn-aiff;audio/x-realaudio;audio/basic;audio/x-basic;audio/x-pn-au;audio/x-8svx;audio/8svx;audio/x-16sv;audio/168sv;image/x-ilbm;image/ilbm;video/x-anim;video/anim;image/png;image/x-png;video/mng;video/x-mng;audio/x-ogg;audio/x-speex+ogg;application/ogg;audio/vnd.rn-realaudio;audio/x-pn-realaudio-plugin;audio/x-real-audio;application/vnd.rn-realmedia;video/mpeg;video/x-mpeg;audio/x-wav;audio/wav;audio/x-pn-wav;audio/x-pn-windows-acm;audio/mpeg2;audio/x-mpeg2;audio/mpeg3;audio/x-mpeg3;audio/mpeg;audio/x-mpeg;audio/x-mpegurl;audio/mp3;audio/x-ape;
X-KDE-Library=phonon_gstreamer
X-KDE-PhononBackendInfo-InterfaceVersion=1
X-KDE-PhononBackendInfo-Version=@PHONON_GST_VERSION@
X-KDE-PhononBackendInfo-Website=http://gstreamer.freedesktop.org/
Icon=phonon-gstreamer
InitialPreference=15

Name=GStreamer
Name[ca]=GStreamer
Name[ca@valencia]=GStreamer
Name[cs]=GStreamer
Name[de]=GStreamer
Name[en_GB]=GStreamer
Name[es]=GStreamer
Name[eu]=GStreamer
Name[fi]=GStreamer
Name[fr]=GStreamer
Name[gl]=GStreamer
Name[id]=GStreamer
Name[is]=GStreamer
Name[it]=GStreamer
Name[ja]=GStreamer
Name[ko]=GStreamer
Name[nb]=GStreamer
Name[nl]=GStreamer
Name[nn]=GStreamer
Name[pl]=GStreamer
Name[pt_BR]=GStreamer
Name[se]=GStreamer
Name[sk]=GStreamer
Name[sr]=Гстример
Name[sr@ijekavian]=Гстример
Name[sr@ijekavianlatin]=GStreamer
Name[sr@latin]=GStreamer
Name[sv]=Gstreamer
Name[uk]=GStreamer
Name[x-test]=xxGStreamerxx
Name[zh_CN]=GStreamer

Comment=Phonon GStreamer backend
Comment[ca]=Dorsal GStreamer del Phonon
Comment[ca@valencia]=Dorsal GStreamer del Phonon
Comment[cs]=Podpůrná vrstva GStreamer pro Phonon
Comment[de]=Phonon-Treiber für GStreamer
Comment[en_GB]=Phonon GStreamer backend
Comment[es]=Motor GStreamer para Phonon
Comment[eu]=Phonon GStreamer bizkarraldekoa
Comment[fi]=Phonon GStreamer -taustajärjestelmä
Comment[fr]=Moteur GStreamer pour Phonon 
Comment[gl]=Infraestrutura de GStreamer para Phonon
Comment[id]=Backend phonon GStreamer
Comment[is]=Phonon GStreamer bakendi
Comment[it]=Motore Gstreamer di Phonon
Comment[ja]=Phonon GStreamer バックエンド
Comment[ko]=Phonon GStreamer 백엔드
Comment[nb]=Phonon-motor for GStreamer
Comment[nl]=GStreamer-backend (Phonon)
Comment[nn]=Phonon-motor for GStreamer
Comment[pl]=Silnik GStreamer Phonona
Comment[pt_BR]=Infraestrutura do GStreamer para o Phonon
Comment[se]=Phonon GStreamer duogášmohtor
Comment[sk]=Podsystém Phonon GStreamer
Comment[sr]=Гстример као позадина Фонона
Comment[sr@ijekavian]=Гстример као позадина Фонона
Comment[sr@ijekavianlatin]=GStreamer kao pozadina Phonona
Comment[sr@latin]=GStreamer kao pozadina Phonona
Comment[sv]=Phonon Gstreamer-gränssnitt
Comment[uk]=Модуль використання GStreamer у Phonon
Comment[x-test]=xxPhonon GStreamer backendxx
Comment[zh_CN]=Phonon GStreamer 后端
